@@ -6,7 +6,7 @@
 #define CLANG_CONFIG_H
 
 /* Bug report URL. */
-#define BUG_REPORT_URL ""
+#define BUG_REPORT_URL "https://bugs.llvm.org/"
 
 /* Default linker to use. */
 #define CLANG_DEFAULT_LINKER ""
@@ -35,6 +35,9 @@
 /* Default architecture for OpenMP offloading to Nvidia GPUs. */
 #define CLANG_OPENMP_NVPTX_DEFAULT_ARCH "sm_35"
 
+/* Default architecture for SystemZ. */
+#define CLANG_SYSTEMZ_DEFAULT_ARCH "z10"
+
 /* Multilib suffix for libdir. */
 #define CLANG_LIBDIR_SUFFIX ""
 
@@ -61,7 +64,7 @@
 #define CLANG_HAVE_RLIMITS 1
 
 /* The LLVM product name and version */
-#define BACKEND_PACKAGE_STRING "LLVM 9.0.1"
+#define BACKEND_PACKAGE_STRING "LLVM 13.0.0"
 
 /* Linker version detected at compile time. */
 /* #undef HOST_LINK_VERSION */
@@ -70,14 +73,14 @@
 /* #undef ENABLE_LINKER_BUILD_ID */
 
 /* enable x86 relax relocations by default */
-#define ENABLE_X86_RELAX_RELOCATIONS 0
-
-/* Enable the experimental new pass manager by default */
-#define ENABLE_EXPERIMENTAL_NEW_PASS_MANAGER 0
+#define ENABLE_X86_RELAX_RELOCATIONS 1
 
 /* Enable each functionality of modules */
 #define CLANG_ENABLE_ARCMT 1
 #define CLANG_ENABLE_OBJC_REWRITER 1
 #define CLANG_ENABLE_STATIC_ANALYZER 1
 
+/* Spawn a new process clang.exe for the CC1 tool invocation, when necessary */
+#define CLANG_SPAWN_CC1 0
+
 #endif
